from dataclasses import dataclass
from datetime import datetime
from typing import Literal, Self, Any

type EntityId = int
type EntityType = Literal["post", "page", "attachment"]


@dataclass(eq=True, frozen=True)
class Record:
    """Record of the views of a given url at a given timestamp.

    It also stores a bit more details about the entity at the given URL (namely id, title and type).
    """

    url: str
    view_count: int
    timestamp: datetime

    entity_id: EntityId
    entity_title: str
    entity_type: EntityType

    @classmethod
    def from_dict_and_timestamp(cls, d: dict[str, Any], timestamp: datetime) -> Self:
        return cls(
            url=d["url"],
            view_count=d["view_cnt"],
            timestamp=timestamp,
            entity_id=d["ID"],
            entity_title=d["post_title"],
            entity_type=d["post_type"],
        )
